@@ -1,7 +1,7 @@
 from django.contrib import admin
 from django.utils.html import format_html
 from edc_adverse_event.modeladmin_mixins import AeInitialModelAdminMixin
-from edc_model_admin import SimpleHistoryAdmin
+from edc_model_admin.history import SimpleHistoryAdmin
 from edc_notification.utils import get_email_contacts
 
 from ..admin_site import meta_ae_admin
