@@ -81,9 +81,9 @@ INSTALLED_APPS = [
     "django.contrib.messages",
     "django.contrib.staticfiles",
     "django.contrib.sites",
-    # "debug_toolbar",
     "defender",
     "multisite",
+    "fontawesomefree",
     "django_crypto_fields.apps.AppConfig",
     "django_revision.apps.AppConfig",
     "django_extensions",
@@ -111,6 +111,7 @@ INSTALLED_APPS = [
     "edc_lab_dashboard.apps.AppConfig",
     "edc_label.apps.AppConfig",
     "edc_list_data.apps.AppConfig",
+    "edc_listboard.apps.AppConfig",
     "edc_identifier.apps.AppConfig",
     "edc_locator.apps.AppConfig",
     "edc_metadata.apps.AppConfig",
@@ -129,6 +130,7 @@ INSTALLED_APPS = [
     "edc_qol.apps.AppConfig",
     "edc_randomization.apps.AppConfig",
     "edc_reference.apps.AppConfig",
+    "edc_refusal.apps.AppConfig",
     "edc_registration.apps.AppConfig",
     "edc_pdf_reports.apps.AppConfig",
     "edc_review_dashboard.apps.AppConfig",
@@ -140,7 +142,6 @@ INSTALLED_APPS = [
     "edc_form_describer.apps.AppConfig",
     "edc_adherence.apps.AppConfig",
     "edc_dx.apps.AppConfig",
-    "edc_refusal.apps.AppConfig",
     "canned_views.apps.AppConfig",
     "meta_consent.apps.AppConfig",
     "meta_data_manager.apps.AppConfig",
@@ -165,7 +166,6 @@ if not DEFENDER_ENABLED:
     INSTALLED_APPS.pop(INSTALLED_APPS.index("defender"))
 
 MIDDLEWARE = [
-    # "debug_toolbar.middleware.DebugToolbarMiddleware",
     "django.middleware.security.SecurityMiddleware",
     "django.contrib.sessions.middleware.SessionMiddleware",
     "django.middleware.common.CommonMiddleware",
@@ -187,8 +187,9 @@ MIDDLEWARE.extend(
         "edc_subject_dashboard.middleware.DashboardMiddleware",
         "edc_lab_dashboard.middleware.DashboardMiddleware",
         "edc_adverse_event.middleware.DashboardMiddleware",
+        "edc_listboard.middleware.DashboardMiddleware",
+        "edc_review_dashboard.middleware.DashboardMiddleware",
         # 'simple_history.middleware.HistoryRequestMiddleware'
-        # "django_cprofile_middleware.middleware.ProfilerMiddleware",
     ]
 )
 
@@ -205,6 +206,10 @@ TEMPLATES = [
                 "django.template.context_processors.request",
                 "django.contrib.auth.context_processors.auth",
                 "django.contrib.messages.context_processors.messages",
+                "edc_model_admin.context_processors.admin_theme",
+                "edc_constants.context_processor.constants",
+                "edc_appointment.context_processors.constants",
+                "edc_visit_tracking.context_processors.constants",
             ]
         },
     }
@@ -364,6 +369,8 @@ HOLIDAY_FILE = env.str("DJANGO_HOLIDAY_FILE")
 # edc-label
 EDC_LABEL_BROWSER_PRINT_PAGE_AUTO_BACK = env("EDC_LABEL_BROWSER_PRINT_PAGE_AUTO_BACK")
 
+# edc_model_admin
+EDC_MODEL_ADMIN_CSS_THEME = "edc_indigo"
 # edc-mnsi
 EDC_MNSI_MODEL = "meta_subject.mnsi"
 
@@ -449,6 +456,8 @@ DATA_DICTIONARY_APP_LABELS = [
     "meta_screening",
     "meta_ae",
     "edc_appointment",
+    "edc_locator",
+    "edc_offstudy",
 ]
 
 # edc_protocol
@@ -483,6 +492,10 @@ if env("AWS_ENABLED"):
     STATICFILES_STORAGE = "storages.backends.s3boto3.S3Boto3Storage"
     STATIC_URL = f"{os.path.join(AWS_S3_CUSTOM_DOMAIN, AWS_LOCATION)}/"
     STATIC_ROOT = ""
+elif DEBUG:
+    STATIC_URL = env.str("DJANGO_STATIC_URL")
+    STATIC_ROOT = os.path.expanduser("~/source/edc_source/meta-edc/static/")
+
 else:
     # run collectstatic, check nginx LOCATION
     STATIC_URL = env.str("DJANGO_STATIC_URL")
