@@ -1,5 +1,4 @@
 from django import forms
-from edc_action_item.forms.action_item_form_mixin import ActionItemFormMixin
 from edc_form_validators.form_validator import FormValidator
 from edc_form_validators.form_validator_mixin import FormValidatorMixin
 from edc_sites.forms import SiteModelFormMixin
@@ -14,18 +13,16 @@ class OffScheduleFormValidator(FormValidator):
 class OffstudyMedicationForm(
     SiteModelFormMixin,
     FormValidatorMixin,
-    ActionItemFormMixin,
     forms.ModelForm,
 ):
 
     form_validator_cls = OffScheduleFormValidator
 
-    subject_identifier = forms.CharField(
-        label="Subject Identifier",
-        required=False,
-        widget=forms.TextInput(attrs={"readonly": "readonly"}),
-    )
-
     class Meta:
         model = OffstudyMedication
         fields = "__all__"
+        help_text = {"subject_identifier": "(read-only)", "action_identifier": "(read-only)"}
+        widgets = {
+            "subject_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
+            "action_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
+        }
