@@ -1,9 +1,6 @@
 from django.db import models
 from edc_action_item.models import ActionModelMixin
-from edc_identifier.model_mixins import (
-    NonUniqueSubjectIdentifierFieldMixin,
-    TrackingModelMixin,
-)
+from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_model import models as edc_models
 from edc_model.models import OtherCharField
 from edc_sites.models import SiteModelMixin
@@ -17,7 +14,6 @@ class OffstudyMedication(
     NonUniqueSubjectIdentifierFieldMixin,
     SiteModelMixin,
     ActionModelMixin,
-    TrackingModelMixin,
     edc_models.BaseUuidModel,
 ):
 
