@@ -2,10 +2,7 @@ from django.db import models
 from edc_action_item.models import ActionModelMixin
 from edc_constants.choices import YES_NO, YES_NO_UNSURE
 from edc_constants.constants import YES
-from edc_identifier.model_mixins import (
-    NonUniqueSubjectIdentifierFieldMixin,
-    TrackingModelMixin,
-)
+from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_model import models as edc_models
 from edc_sites.models import SiteModelMixin
 from edc_utils import get_utcnow
@@ -23,7 +20,6 @@ class PregnancyNotification(
     NonUniqueSubjectIdentifierFieldMixin,
     SiteModelMixin,
     ActionModelMixin,
-    TrackingModelMixin,
     edc_models.BaseUuidModel,
 ):
 
