@@ -1,9 +1,6 @@
 from django.db import models
 from edc_action_item.models import ActionItem, ActionModelMixin
-from edc_identifier.model_mixins import (
-    NonUniqueSubjectIdentifierFieldMixin,
-    TrackingModelMixin,
-)
+from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_model.models import BaseUuidModel
 from edc_protocol_violation.constants import PROTOCOL_INCIDENT_ACTION
 from edc_protocol_violation.model_mixins import ProtocolIncidentModelMixin
@@ -17,7 +14,6 @@ class ProtocolIncident(
     NonUniqueSubjectIdentifierFieldMixin,
     SiteModelMixin,
     ActionModelMixin,
-    TrackingModelMixin,
     BaseUuidModel,
 ):
 
