@@ -1,7 +1,9 @@
+from django.apps import apps as django_apps
 from edc_action_item import Action, ActionWithNotification, site_action_items
 from edc_action_item.site_action_items import AlreadyRegistered
 from edc_adverse_event.constants import AE_INITIAL_ACTION
 from edc_constants.constants import HIGH_PRIORITY, NEW, NONE, POS, YES
+from edc_egfr.constants import EGFR_DROP_NOTIFICATION_ACTION
 from edc_lab_results.action_items import (
     BloodResultsFbcAction,
     BloodResultsGluAction,
@@ -13,18 +15,18 @@ from edc_lab_results.action_items import (
     BloodResultsRftAction as BaseBloodResultsRftAction,
 )
 from edc_ltfu.constants import LTFU_ACTION
-from edc_offstudy.constants import END_OF_STUDY_ACTION
 from edc_reportable import GRADE3, GRADE4
 from edc_visit_schedule.utils import is_baseline
+from edc_visit_tracking.constants import MISSED_VISIT
 
 from meta_prn.constants import (
+    OFFSCHEDULE_ACTION,
     OFFSCHEDULE_PREGNANCY_ACTION,
     PREGNANCY_NOTIFICATION_ACTION,
 )
 
 from .constants import (
     DELIVERY_ACTION,
-    EGFR_NOTIFICATION_ACTION,
     FOLLOWUP_EXAMINATION_ACTION,
     MISSED_VISIT_ACTION,
     URINE_PREGNANCY_ACTION,
@@ -42,8 +44,23 @@ class MissedVisitAction(Action):
     def get_next_actions(self):
         # TODO: define LTFU, 6 months off study medication
         next_actions = []
-        ltfu = None
-        if ltfu:
+        subjectconsent_model_cls = django_apps.get_model("meta_consent.subjectconsent")
+        subjectvisit_model_cls = django_apps.get_model("meta_subject.subjectvisit")
+        subject_consent = subjectconsent_model_cls.objects.get(
+            subject_identifier=self.subject_identifier
+        )
+        last_visit = (
+            subjectvisit_model_cls.objects.filter(subject_identifier=self.subject_identifier)
+            .exclude(reason=MISSED_VISIT)
+            .order_by("report_datetime")
+            .last()
+        )
+        # last_refill_until
+        # TODO: last_refill_until in below calc
+        if (
+            last_visit
+            and (last_visit.report_datetime - subject_consent.consent_datetime).days >= 182
+        ):
             next_actions = [LTFU_ACTION]
         return next_actions
 
@@ -93,7 +110,7 @@ class BloodResultsRftAction(BaseBloodResultsRftAction):
     def get_next_actions(self):
         next_actions = super().get_next_actions()
         if self.reference_obj.egfr_value is not None and self.reference_obj.egfr_value < 45.0:
-            next_actions = [END_OF_STUDY_ACTION]
+            next_actions.append(OFFSCHEDULE_ACTION)
         return next_actions
 
 
@@ -113,12 +130,12 @@ class DeliveryAction(ActionWithNotification):
         return next_actions
 
 
-class EgfrNotificationAction(ActionWithNotification):
-    name = EGFR_NOTIFICATION_ACTION
+class EgfrDropNotificationAction(ActionWithNotification):
+    name = EGFR_DROP_NOTIFICATION_ACTION
     display_name = "eGFR drop warning"
     notification_display_name = "eGFR drop warning"
     parent_action_names = []
-    reference_model = "meta_subject.egfrnotification"
+    reference_model = "meta_subject.egfrdropnotification"
     show_link_to_changelist = True
     show_link_to_add = True
     admin_site_name = "meta_subject_admin"
@@ -140,12 +157,13 @@ def register_actions():
         MissedVisitAction,
         UrinePregnancyAction,
         DeliveryAction,
-        EgfrNotificationAction,
+        EgfrDropNotificationAction,
     ]:
         try:
             site_action_items.register(action_item_cls)
         except AlreadyRegistered:
-            pass
+            del site_action_items.registry[action_item_cls.name]
+            site_action_items.register(action_item_cls)
 
 
 register_actions()
