@@ -1,5 +1,5 @@
 from django import forms
-from edc_action_item.forms import ActionItemFormMixin
+from edc_action_item.forms import ActionItemCrfFormMixin
 from edc_crf.modelform_mixins import CrfModelFormMixin
 from edc_form_validators import FormValidator
 from edc_lab_panel.panels import hba1c_panel, hba1c_poc_panel
@@ -12,10 +12,10 @@ class BloodResultsHba1cFormValidator(BloodResultsFormValidatorMixin, FormValidat
     panels = [hba1c_poc_panel, hba1c_panel]
 
 
-class BloodResultsHba1cForm(ActionItemFormMixin, CrfModelFormMixin, forms.ModelForm):
+class BloodResultsHba1cForm(ActionItemCrfFormMixin, CrfModelFormMixin, forms.ModelForm):
 
     form_validator_cls = BloodResultsHba1cFormValidator
 
-    class Meta:
+    class Meta(ActionItemCrfFormMixin.Meta):
         model = BloodResultsHba1c
         fields = "__all__"
