@@ -1,5 +1,5 @@
 from django import forms
-from edc_action_item.forms import ActionItemFormMixin
+from edc_action_item.forms import ActionItemCrfFormMixin
 from edc_crf.modelform_mixins import CrfModelFormMixin
 from edc_form_validators import FormValidator
 from edc_lab_panel.panels import insulin_panel
@@ -12,10 +12,10 @@ class BloodResultsInsFormValidator(BloodResultsFormValidatorMixin, FormValidator
     panel = insulin_panel
 
 
-class BloodResultsInsForm(ActionItemFormMixin, CrfModelFormMixin, forms.ModelForm):
+class BloodResultsInsForm(ActionItemCrfFormMixin, CrfModelFormMixin, forms.ModelForm):
 
     form_validator_cls = BloodResultsInsFormValidator
 
-    class Meta:
+    class Meta(ActionItemCrfFormMixin.Meta):
         model = BloodResultsIns
         fields = "__all__"
