@@ -1,5 +1,5 @@
 from django import forms
-from edc_action_item.forms import ActionItemFormMixin
+from edc_action_item.forms import ActionItemCrfFormMixin
 from edc_crf.modelform_mixins import CrfModelFormMixin
 from edc_form_validators import FormValidator
 from edc_lab_panel.panels import lft_panel
@@ -12,10 +12,10 @@ class BloodResultsLftFormValidator(BloodResultsFormValidatorMixin, FormValidator
     panel = lft_panel
 
 
-class BloodResultsLftForm(ActionItemFormMixin, CrfModelFormMixin, forms.ModelForm):
+class BloodResultsLftForm(ActionItemCrfFormMixin, CrfModelFormMixin, forms.ModelForm):
 
     form_validator_cls = BloodResultsLftFormValidator
 
-    class Meta:
+    class Meta(ActionItemCrfFormMixin.Meta):
         model = BloodResultsLft
         fields = "__all__"
