@@ -8,8 +8,7 @@ from ..model_mixins import CrfModelMixin
 class DietAndLifestyle(CrfModelMixin, edc_models.BaseUuidModel):
     diet_and_lifestyle = models.CharField(
         verbose_name=(
-            "Has the participant received the META3 "
-            "approved diet and lifetsyle counseling?"
+            "Has the participant received the META3 " "approved diet and lifetsyle counseling?"
         ),
         max_length=15,
         choices=YES_NO,
