@@ -115,6 +115,7 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "edc_lab.apps.AppConfig",
         "edc_lab_dashboard.apps.AppConfig",
         "edc_label.apps.AppConfig",
+        "edc_listboard.apps.AppConfig",
         "edc_locator.apps.AppConfig",
         "edc_reference.apps.AppConfig",
         "edc_pdf_reports.apps.AppConfig",
@@ -139,6 +140,7 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "edc_timepoint.apps.AppConfig",
         "edc_list_data.apps.AppConfig",
         "edc_review_dashboard.apps.AppConfig",
+        "edc_refusal.apps.AppConfig",
         "edc_sites.apps.AppConfig",
         "edc_mnsi.apps.AppConfig",
         "edc_unblinding.apps.AppConfig",
